/*
 * Copyright 2010 Sergey Martynov http://studiomobile.ru
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ru.studiomobile.android.http;

import org.apache.http.Header;
import org.apache.http.HttpEntity;
import org.apache.http.HttpRequest;
import org.apache.http.nio.reactor.IOReactorStatus;
import org.apache.http.params.HttpParams;
import ru.studiomobile.http.BasicHttpClient;
import ru.studiomobile.http.HttpClient;
import ru.studiomobile.http.HttpClientHelper;
import ru.studiomobile.http.HttpRequestFuture;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.URL;

public class AndroidHttpClient extends HttpClientHelper implements HttpClient {
    private final HttpClient client;

    public AndroidHttpClient(HttpClient client) {
        this.client = client;
    }

    public AndroidHttpClient(HttpParams config) throws IOException {
        this(new BasicHttpClient(config));
    }

    public AndroidHttpClient() throws IOException {
        this(new BasicHttpClient());
    }

    public HttpRequestFuture executeRequest(InetSocketAddress address, HttpRequest request) {
        return new AndroidHttpRequestFutureAdapter(client.executeRequest(address, request));
    }

    public HttpRequestFuture head(URL url, Header... headers) {
        return new AndroidHttpRequestFutureAdapter(client.head(url, headers));
    }

    public HttpRequestFuture get(URL url, Header... headers) {
        return new AndroidHttpRequestFutureAdapter(client.get(url, headers));
    }

    public HttpRequestFuture post(URL url, HttpEntity entity, Header... headers) {
        return new AndroidHttpRequestFutureAdapter(client.post(url, entity, headers));
    }

    public HttpRequestFuture put(URL url, HttpEntity entity, Header... headers) {
        return new AndroidHttpRequestFutureAdapter(client.put(url, entity, headers));
    }

    public HttpRequestFuture delete(URL url, Header... headers) {
        return new AndroidHttpRequestFutureAdapter(client.delete(url, headers));
    }

    public IOReactorStatus getStatus() {
        return client.getStatus();
    }

    public void shutdown(long waitMs) throws IOException {
        client.shutdown(waitMs);
    }

    public void shutdown() throws IOException {
        client.shutdown();
    }
}
