/*
 * Copyright 2010 Sergey Martynov http://studiomobile.ru
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ru.studiomobile.android.http;

import android.os.Handler;
import org.apache.http.HttpResponse;
import ru.studiomobile.http.HttpClientListener;
import ru.studiomobile.http.HttpRequestFuture;

public class AndroidHttpClientListener implements HttpClientListener {

    private final Handler handler;
    private final HttpClientListener listener;

    public AndroidHttpClientListener(Handler handler, HttpClientListener listener) {
        this.handler = handler;
        this.listener = listener;
    }

    public HttpClientListener getListener() {
        return listener;
    }

    public void requestFinished(final HttpRequestFuture future, final HttpResponse response) {
        handler.post(new Runnable() {
            public void run() {
                listener.requestFinished(future, response);
            }
        });
    }

    public void requestFailed(final HttpRequestFuture future) {
        handler.post(new Runnable() {
            public void run() {
                listener.requestFailed(future);
            }
        });
    }

    public void requestCancelled(final HttpRequestFuture future) {
        handler.post(new Runnable() {
            public void run() {
                listener.requestCancelled(future);
            }
        });
    }
}
