/*
 * Copyright 2010 Sergey Martynov http://studiomobile.ru
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package ru.studiomobile.android.http;

import android.os.Handler;
import org.apache.http.HttpRequest;
import org.apache.http.HttpResponse;
import ru.studiomobile.http.HttpClientListener;
import ru.studiomobile.http.HttpRequestFuture;

import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;

public class AndroidHttpRequestFutureAdapter implements HttpRequestFuture {

    private final HttpRequestFuture future;
    private AndroidHttpClientListener listener;

    public AndroidHttpRequestFutureAdapter(HttpRequestFuture future) {
        this.future = future;
    }

    public HttpRequest getRequest() {
        return future.getRequest();
    }

    public Iterable<HttpRequest> getRedirects() {
        return future.getRedirects();
    }

    public Exception getError() {
        return future.getError();
    }

    public HttpClientListener getListener() {
        return listener != null ? listener.getListener() : null;
    }

    public void setListener(HttpClientListener listener) {
        this.listener = new AndroidHttpClientListener(new Handler(), listener);
        future.setListener(this.listener);
    }

    public boolean cancel(boolean b) {
        return future.cancel(b);
    }

    public boolean isCancelled() {
        return future.isCancelled();
    }

    public boolean isDone() {
        return future.isDone();
    }

    public HttpResponse get() throws InterruptedException, ExecutionException {
        return future.get();
    }

    public HttpResponse get(long l, TimeUnit timeUnit) throws InterruptedException, ExecutionException, TimeoutException {
        return future.get(l, timeUnit);
    }
}
